declare function saslprep(input: string, opts?: {
    allowUnassigned?: boolean;
}): string;
declare namespace saslprep {
    export var saslprep: typeof import("./node");
    var _a: typeof import("./node");
    export { _a as default };
}
export = saslprep;
//# sourceMappingURL=node.d.ts.map