"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.range = range;
function range(from, to) {
    const list = new Array(to - from + 1);
    for (let i = 0; i < list.length; i += 1) {
        list[i] = from + i;
    }
    return list;
}
//# sourceMappingURL=util.js.map